@@ -2,6 +2,7 @@ import logging
 import os.path
 import sys
 import zipfile
+from typing import Optional
 
 from easyprocess import EasyProcess
 
@@ -15,7 +16,7 @@ class PatoolError(Exception):
     pass
 
 
-def _fullpath(x):
+def _fullpath(x: str) -> str:
     x = os.path.expandvars(x)
     x = os.path.expanduser(x)
     x = os.path.normpath(x)
@@ -23,52 +24,70 @@ def _fullpath(x):
     return x
 
 
-def _exepath(cmd):
+def _exepath(cmd: str) -> Optional[str]:
     for p in os.environ["PATH"].split(os.pathsep):
         fullp = os.path.join(p, cmd)
         if os.access(fullp, os.X_OK):
             return fullp
+    return None
 
 
 class Archive(object):
-
     """
     :param backend: ``auto``, ``patool`` or ``zipfile``
     :param filename: path to archive file
     """
 
-    def __init__(self, filename, backend="auto", timeout=None):
+    def __init__(
+        self,
+        filename: str,
+        backend: str = "auto",
+        timeout: Optional[float] = None,
+        password: Optional[str] = None,
+    ):
         self.filename = _fullpath(filename)
         self.backend = backend
         self.timeout = timeout
+        self.password = password
 
-    def extractall_patool(self, directory, patool_path):
+    def extractall_patool(self, directory: str, patool_path: Optional[str]) -> None:
         log.debug("starting backend patool")
         if not patool_path:
             patool_path = _exepath("patool")
         if not patool_path:
             raise ValueError("patool not found! Please install patool!")
-        p = EasyProcess(
-            [
-                sys.executable,
-                patool_path,
-                "--non-interactive",
-                "extract",
-                self.filename,
-                "--outdir=" + directory,
-                #                     '--verbose',
-            ]
-        ).call(timeout=self.timeout)
+        patool_cmd = [
+            sys.executable,
+            patool_path,
+            "--non-interactive",
+            "extract",
+            self.filename,
+            "--outdir=" + directory,
+            #                     '--verbose',
+        ]
+        if self.password is not None:
+            patool_cmd.extend(["--password", str(self.password)])
+        p = EasyProcess(patool_cmd).call(timeout=self.timeout)
         if p.timeout_happened:
             raise PatoolError("patool timeout\n" + str(p.stdout) + "\n" + str(p.stderr))
         if p.return_code:
             raise PatoolError("patool can not unpack\n" + str(p.stderr))
 
-    def extractall_zipfile(self, directory):
+    def extractall_zipfile(self, directory: str) -> None:
         log.debug("starting backend zipfile")
-        zipfile.ZipFile(self.filename).extractall(directory)
+        if self.password is not None:
+            zipfile.ZipFile(self.filename).extractall(
+                directory, pwd=str(self.password).encode("utf-8")
+            )
+        else:
+            zipfile.ZipFile(self.filename).extractall(directory)
 
-    def extractall(self, directory, auto_create_dir=False, patool_path=None):
+    def extractall(
+        self,
+        directory: str,
+        auto_create_dir: bool = False,
+        patool_path: Optional[str] = None,
+    ) -> None:
         """
         :param directory: directory to extract to
         :param auto_create_dir: auto create directory
